# falco-ui

[![PyPI - Version](https://img.shields.io/pypi/v/falco-ui.svg)](https://pypi.org/project/falco-ui)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/falco-ui.svg)](https://pypi.org/project/falco-ui)

-----

> [!IMPORTANT]
> This package currently contains minimal features and is a work-in-progress


**Table of Contents**

- [falco-ui](#falco-ui)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install falco-ui
```

## License

`falco-ui` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
